GridImage class

Constructors

GridImage(String _path)
GridImage.fromAsset(String _path)
GridImage.fromAssetPart(String _path, double x, double y, double width, double height)

Properties

hashCode → int
The hash code for this object.
no setterinherited
height ↔ double
getter/setter pair
id ↔ String
getter/setter pair
path ← String
no getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uiImage ↔ Image
getter/setter pair
width ↔ double
getter/setter pair
withPart ↔ bool
getter/setter pair
x ↔ double
getter/setter pair
y ↔ double
getter/setter pair

Methods

initUiImage() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited